@@ -27,7 +27,7 @@
 #include "resource.h"
 #include "layout.h"
 #include "connectioneditorimpl.h"
-#include <widgetdatabase.h>
+#include "widgetdatabase.h"
 #include "pixmapchooser.h"
 #include "orderindicator.h"
 #include "hierarchyview.h"
@@ -44,11 +44,9 @@
 #include <qlabel.h>
 #include <qobjectlist.h>
 #include <qtimer.h>
-#include <qapplication.h>
 #include <qlayout.h>
 #include <qspinbox.h>
 #include <qstatusbar.h>
-#include <qapplication.h>
 #include <qpalette.h>
 #include <qmessagebox.h>
 #include <qpopupmenu.h>
@@ -61,6 +59,7 @@
 #include <qaccel.h>
 #include <qpixmapcache.h>
 #include <qbitmap.h>
+#include <qapplication.h>
 
 #ifdef HAVE_KDE
 #include <kstatusbar.h>
