@@ -25,10 +25,10 @@
 #include "formwindow.h"
 #include "mainwindow.h"
 #include "qdom.h"
-#include <widgetdatabase.h>
+#include "widgetdatabase.h"
 #include "widgetfactory.h"
 #include "layout.h"
-#include <domtool.h>
+#include "domtool.h"
 #include "command.h"
 #include "pixmapchooser.h"
 #ifndef QT_NO_SQL
@@ -49,13 +49,11 @@
 #include <qobjectlist.h>
 #include <qmetaobject.h>
 #include <qworkspace.h>
-#include <qtabwidget.h>
 #include <qapplication.h>
 #include <qbuffer.h>
 #include <qlayout.h>
 #include <qtooltip.h>
 #include <qwhatsthis.h>
-#include <qtabwidget.h>
 #include <qlistbox.h>
 #include <qcombobox.h>
 #include <qwidgetstack.h>
