@@ -18,10 +18,10 @@ class ComboBox : public QComboBox, public AssocTextWidget
 {
 	Q_OBJECT
 
-	Q_PROPERTY(QStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false);
-	Q_PROPERTY(bool AssocTextWidget READ isAssociatedTextWidget);
+	Q_PROPERTY(QStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
+	Q_PROPERTY(bool AssocTextWidget READ isAssociatedTextWidget)
 	
-	Q_PROPERTY(QStringList items READ items WRITE setItems RESET resetItems);
+	Q_PROPERTY(QStringList items READ items WRITE setItems RESET resetItems)
 public:
 	ComboBox(QWidget *a_parent, const char *a_name);
 	~ComboBox();
