@@ -18,8 +18,8 @@ class ListBox : public QListBox, public AssocTextWidget
 {
 	Q_OBJECT
 
-	Q_PROPERTY(QStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false);
-	Q_PROPERTY(bool AssocTextWidget READ isAssociatedTextWidget);
+	Q_PROPERTY(QStringList associations READ associatedText WRITE setAssociatedText DESIGNABLE false)
+	Q_PROPERTY(bool AssocTextWidget READ isAssociatedTextWidget)
 public:
 	ListBox(QWidget *a_parent, const char *a_name);
 	~ListBox();
