@@ -50,6 +50,7 @@
 #include <kparts/componentfactory.h>
 #include <kprogress.h>
 #include <kspell.h>
+#include <kdebug.h>
 
 #include <kio/netaccess.h>
 
@@ -67,7 +68,6 @@
 #include "widgets/whtmlpart.h"
 #include "messages/messageoutput.h"
 
-#include "treeviews/fileslistview.h"
 #include "treeviews/filestreeview.h"
 #include "treeviews/projecttreeview.h"
 #include "treeviews/doctreeview.h"
@@ -87,7 +87,7 @@
 #include "parser/parser.h"
 #include "dialogs/filemasks.h"
 
-QuantaApp::QuantaApp() : KDockMainWindow(0L,"Quanta")
+QuantaApp::QuantaApp() : KDockMainWindow(0L,"Quanta"), DCOPObject("WindowManagerIf")
 {
   quantaStarted = true;
   tempFileList.setAutoDelete(true);
@@ -133,8 +133,14 @@ QuantaApp::~QuantaApp()
  toolbarList.clear();
  delete spellChecker;
  QStringList tmpDirs = KGlobal::dirs()->resourceDirs("tmp");
+ tmpDir = tmpDirs[0];
+ for (uint i = 0; i < tmpDirs.count(); i++)
+ {
+   if (tmpDirs[i].contains("kde-"))
+      tmpDir = tmpDirs[i];
+ }
  QDir dir;
- dir.rmdir(tmpDirs[0] + "quanta");
+ dir.rmdir(tmpDir + "quanta");
 }
 
 
@@ -145,8 +151,14 @@ void QuantaApp::initQuanta()
 
   QStringList tmpDirs = KGlobal::dirs()->resourceDirs("tmp");
   QDir dir;
-  dir.mkdir(tmpDirs[0] + "quanta");
-  tmpDir = tmpDirs[0] + "quanta/quanta";
+  tmpDir = tmpDirs[0];
+  for (uint i = 0; i < tmpDirs.count(); i++)
+  {
+    if (tmpDirs[i].contains("kde-"))
+       tmpDir = tmpDirs[i];
+  }
+  dir.mkdir(tmpDir + "quanta");
+  tmpDir += "quanta/quanta";
 
   initTagDict  ();
   initStatusBar();
@@ -158,29 +170,6 @@ void QuantaApp::initQuanta()
 
   readOptions();
 
-//Check for an existing quanatui.rc
-  QString uiFileName = locateLocal("appdata","quantaui.rc");
-  if (QFileInfo(uiFileName).exists())
-  {
-    QDomDocument doc;
-     QFile f( uiFileName );
-		 f.open( IO_ReadOnly );
-	   if ( doc.setContent( &f ) )
-     {
-       f.close();
-       QDomElement el = doc.firstChild().toElement();
-       if (el.attribute("version","old") != QString(VERSION))
-       {
-         QString command = "mv "+uiFileName+" "+uiFileName+".old";
-         system(QFile::encodeName(command));
-       }
-     } else
-     {
-       f.close();
-     }
-  }
-
-
   m_pluginInterface = new QuantaPluginInterface();
 
   createGUI( QString::null, false /* conserveMemory */ );
@@ -236,6 +225,7 @@ void QuantaApp::initStatusBar()
   connect(statusbarTimer,SIGNAL(timeout()),this,SLOT(statusBarTimeout()));
 
   progressBar = new KProgress(statusBar());
+  progressBar->setMaximumHeight( fontMetrics().height() );
   progressBar->show();
   statusBar()->insertItem(i18n(IDS_DEFAULT),IDS_STATUS, 1);
   statusBar()->addWidget(progressBar);
@@ -281,13 +271,9 @@ void QuantaApp::initProject()
   connect(project,  SIGNAL(templateURLChanged(const KURL &)),
           tTab,     SLOT  (slotSetTemplateURL(const KURL &)));
 
-  connect(fLTab,    SIGNAL(insertDirInProject(const KURL&)),
-          project,  SLOT  (slotAddDirectory(const KURL&)));
   connect(fTTab,    SIGNAL(insertDirInProject(const KURL&)),
           project,  SLOT  (slotAddDirectory(const KURL&)));
 
-  connect(fLTab,    SIGNAL(insertFileInProject(const KURL&)),
-          project,  SLOT  (slotInsertFile(const KURL&)));
   connect(fTTab,    SIGNAL(insertFileInProject(const KURL&)),
           project,  SLOT  (slotInsertFile(const KURL&)));
 
@@ -341,6 +327,7 @@ void QuantaApp::initView()
   stabdock->setToolTipString(i18n("Structure view (DOM tree)"));
   dtabdock = createDockWidget("Docs", BarIcon ("contents2"),    0L,"" /*i18n("Docs")*/);
   dtabdock->setToolTipString(i18n("Documentation"));
+  m_oldTreeViewWidget = ptabdock;
 
   QStringList topStrList;
   config->setGroup("General Options");
@@ -362,10 +349,8 @@ void QuantaApp::initView()
 
   fTab = new QWidgetStack( ftabdock );
   fTTab = new FilesTreeView(topList, fTab );
-  fLTab = new FilesListView( QDir::homeDirPath()+"/" , 0L, fTab );
 
   fTab -> addWidget( fTTab, 0 );
-  fTab -> addWidget( fLTab, 1 );
   fTab -> raiseWidget( 0 );
 
   pTab  = new ProjectTreeView( ptabdock );
@@ -394,7 +379,6 @@ void QuantaApp::initView()
 
   fTab  ->setFocusPolicy(QWidget::NoFocus);
   fTTab ->setFocusPolicy(QWidget::ClickFocus);
-  fLTab ->setFocusPolicy(QWidget::ClickFocus);
   pTab  ->setFocusPolicy(QWidget::NoFocus);
   tTab  ->setFocusPolicy(QWidget::NoFocus);
   sTab  ->setFocusPolicy(QWidget::NoFocus);
@@ -421,18 +405,9 @@ void QuantaApp::initView()
 
   connect(   fTTab,SIGNAL(openFile  (const KURL &, const QString&)),
             this, SLOT(slotFileOpen(const KURL &, const QString&)));
-  connect(   fLTab,SIGNAL(openFile  (const KURL &, const QString&)),
-            this, SLOT(slotFileOpen(const KURL &, const QString&)));
 
   connect(   fTTab,SIGNAL(openImage(const KURL&)),
             this, SLOT  (slotImageOpen(const KURL&)));
-  connect(   fLTab,SIGNAL(openImage(const KURL&)),
-            this, SLOT  (slotImageOpen(const KURL&)));
-
-  connect(  fLTab,SIGNAL(changeMode()),
-            this, SLOT(slotSwapLeftPanelMode()));
-  connect(  fTTab,SIGNAL(changeMode()),
-            this, SLOT(slotSwapLeftPanelMode()));
 
   connect(   pTab, SIGNAL(openFile  (const KURL &, const QString&)),
             this, SLOT(slotFileOpen(const KURL &, const QString&)));
@@ -452,13 +427,9 @@ void QuantaApp::initView()
 
   connect(   fTTab,SIGNAL(insertTag(const KURL &, DirInfo)),
             this, SLOT(slotInsertTag(const KURL &, DirInfo)));
-  connect(   fLTab,SIGNAL(insertTag(const KURL &, DirInfo)),
-            this, SLOT(slotInsertTag(const KURL &, DirInfo)));
   connect(   pTab,SIGNAL(insertTag(const KURL &, DirInfo)),
             this, SLOT(slotInsertTag(const KURL &, DirInfo)));
 
-  connect(   fLTab,SIGNAL(activatePreview()),
-            this, SLOT(slotActivatePreview()));
   connect(   fTTab,SIGNAL(activatePreview()),
             this, SLOT(slotActivatePreview()));
   connect(   pTab, SIGNAL(activatePreview()),
@@ -541,7 +512,7 @@ void QuantaApp::saveOptions()
 
     config->writeEntry("Capitals for tags", qConfig.tagCase);
     config->writeEntry("Capitals for attr", qConfig.attrCase);
-    config->writeEntry("Attribute quotation", qConfig.attrValueQuotation);
+    config->writeEntry("Attribute quotation", qConfig.attrValueQuotation=='"' ? "double":"single");
     config->writeEntry("Close tag if optional", qConfig.closeOptionalTags);
     config->writeEntry("Close tags", qConfig.closeTags);
     config->writeEntry("Auto completion", qConfig.useAutoCompletion);
@@ -551,7 +522,6 @@ void QuantaApp::saveOptions()
     config->writeEntry("Default encoding", qConfig.defaultEncoding);
     config->writeEntry("Default DTD", qConfig.defaultDocType);
     config->writeEntry("New File Type", qConfig.newFileType);
-    config->writeEntry("Use MimeTypes", qConfig.useMimeTypes);
 
     config->writeEntry("Refresh frequency", qConfig.refreshFrequency);
 
@@ -562,17 +532,32 @@ void QuantaApp::saveOptions()
     config->writeEntry("Top folders", fTTab->topURLList.toStringList());
     config->writeEntry("List of opened files", doc->openedFiles().toStringList());
     config->writeEntry("Version", VERSION); // version
-    doc    ->writeConfig(config); // kwrites
-    project->writeConfig(config); // project
-    config->setGroup  ("General Options");
-    config->deleteGroup("RecentFiles");
-    fileRecent->saveEntries(config);
     config->writeEntry ("Enable Debugger", debuggerStyle!="None");
     config->writeEntry ("PHP Debugger style", debuggerStyle);
+    if (view->writeExists())
+        view->write()->writeConfig(config);
+
+    config->deleteGroup("RecentFiles");
+    fileRecent->saveEntries(config);
+    //doc    ->writeConfig(config); // kwrites
+    project->writeConfig(config); // project
     writeDockConfig(config);
     saveMainWindowSettings(config);
     spellChecker->writeConfig(config);
+
+    config->setGroup("Kate View");
+    config->writeEntry("LineNumbers", qConfig.lineNumbers);
+    config->writeEntry("Iconbar", qConfig.iconBar);
+    config->writeEntry("DynamicWordWrap",qConfig.dynamicWordWrap);
     config->sync();
+
+    view->write()->kate_view->setIconBorder(qConfig.iconBar);
+    view->write()->kate_view->setLineNumbersOn(qConfig.lineNumbers);
+
+#if (KDE_VERSION > 308)
+    dynamic_cast<KTextEditor::DynWordWrapInterface *>(view->write()->view())->setDynWordWrap(qConfig.dynamicWordWrap);
+#endif
+
   }
 }
 
@@ -591,7 +576,7 @@ void QuantaApp::readOptions()
 
   qConfig.tagCase = config->readNumEntry("Capitals for tags", 0);
   qConfig.attrCase = config->readNumEntry("Capitals for attr", 0);
-  qConfig.attrValueQuotation = config->readEntry("Attribute quotation", "double");
+  qConfig.attrValueQuotation = (config->readEntry("Attribute quotation", "double") == "double" )? '"':'\'';
   qConfig.closeOptionalTags = config->readBoolEntry("Close tag if optional", true);
   qConfig.closeTags = config->readBoolEntry("Close tags", true);
   qConfig.useAutoCompletion = config->readBoolEntry("Auto completion",true);
@@ -605,7 +590,6 @@ void QuantaApp::readOptions()
      qConfig.newFileType = qConfig.defaultDocType;
 
   qConfig.defaultEncoding = config->readEntry("Default encoding", QTextCodec::codecForLocale()->name());
-  qConfig.useMimeTypes = config->readBoolEntry("Use MimeTypes", false);
 
   qConfig.refreshFrequency = config->readNumEntry("Refresh frequency",5);
 
@@ -614,10 +598,6 @@ void QuantaApp::readOptions()
   sTab->setFollowCursor( config->readBoolEntry("Follow Cursor", true));
 
   qConfig.previewPosition   = config->readEntry("Preview position","Right");
-  int mode = config->readNumEntry("Left panel mode", 0);
-/* List Mode disabled!!
-  if ( mode == 0 || mode == 1 ) fTab->raiseWidget(mode);
-*/
   fTab->raiseWidget(0);
 
   fileRecent ->loadEntries(config);
@@ -649,9 +629,7 @@ void QuantaApp::readOptions()
   showToolbarAction  ->setChecked(config->readBoolEntry("Show Toolbar",   true));
   showStatusbarAction->setChecked(config->readBoolEntry("Show Statusbar", true));
   qConfig.enableDTDToolbar = config->readBoolEntry("Show DTD Toolbar",true);
-
-  slotToggleDTDToolbar(qConfig.enableDTDToolbar);
-  showDTDToolbar->setEnabled(qConfig.enableDTDToolbar);
+  showDTDToolbar->setChecked(qConfig.enableDTDToolbar);
 
   config->setGroup("Kate View");
   qConfig.lineNumbers = config->readBoolEntry("LineNumbers", false);
@@ -764,11 +742,12 @@ bool QuantaApp::queryClose()
   {
     exitingFlag = true;
     saveOptions();
-    saveModifiedToolbars();
     canExit = doc->saveAll(false);
+    if (canExit)
+	canExit = saveModifiedToolbars();
     if (canExit)
     {
-      //avoid double question about saving files, so set the "modified"
+      disconnect( view->writeTab, SIGNAL(currentChanged(QWidget*)), this, SLOT(slotUpdateStatus(QWidget*)));      //avoid double question about saving files, so set the "modified"
       //flags to "false". This is safe here.
       Document *w;
       for (int i = view->writeTab->count() -1; i >=0; i--)
@@ -898,7 +877,13 @@ uint QuantaApp::readTagFile(QString fileName, DTDStruct* parentDTD, QTagList *ta
  QFile f( fileName );
  f.open( IO_ReadOnly );
  QDomDocument *doc = new QDomDocument();
- doc->setContent( &f );
+ QString errorMsg;
+ int errorLine, errorCol;
+ if (!doc->setContent( &f, &errorMsg, &errorLine, &errorCol ))
+ {
+   kdWarning() << fileName << ": " << errorMsg << ": " << errorLine << "," << errorCol << endl;
+ }
+
  f.close();
 
  for ( QDomNode n = doc->firstChild().firstChild(); !n.isNull(); n = n.nextSibling() )
@@ -942,6 +927,14 @@ void QuantaApp::readTagDir(QString &dirName)
  dtd->name = dtdName.lower();
  dtd->nickName = dtdConfig->readEntry("NickName", dtdName);
  dtd->url = dtdConfig->readEntry("URL");
+ dtd->doctypeStr = dtdConfig->readEntry("DoctypeString");
+ if (dtd->doctypeStr.isEmpty())
+ {
+   dtd->doctypeStr = "PUBLIC \"" + dtdName + "\"";
+   if (!dtd->url.isEmpty())
+      dtd->doctypeStr += " \"" + dtd->url + "\"";
+ }
+ dtd->doctypeStr.prepend(' ');
  dtd->inheritsTagsFrom = dtdConfig->readEntry("Inherits");
 
  dtd->defaultExtension = dtdConfig->readEntry("DefaultExtension", "html");
@@ -1199,6 +1192,7 @@ void QuantaApp::initActions()
     KStdAction::deselect(view, SLOT(slotDeselectAll()),actionCollection());
     (void) new KAction( i18n( "&Toggle Block Selection" ), Key_F4, view,
                         SLOT( toggleVertical() ), actionCollection(), "set_verticalSelect" );
+    (void) new KAction(i18n("Toggle &Insert"), Key_Insert, view, SLOT(toggleInsert()), actionCollection(), "set_insert" );
 
 
     KStdAction::find(view, SLOT(slotFind()), actionCollection());
@@ -1243,7 +1237,7 @@ void QuantaApp::initActions()
   {
     viewDynamicWordWrap = new KToggleAction(i18n("&Dynamic Word Wrap"), Key_F12, view,
                               SLOT(toggleDynamicWordWrap()), actionCollection(), "view_dynamic_word_wrap");
-  }                                                         
+  }
 
   (void) new KAction( i18n( "Configure &Editor..." ), SmallIcon("configure"), 0,
                       view, SLOT( slotEditorOptions() ), actionCollection(), "editor_options" );
@@ -1263,15 +1257,16 @@ void QuantaApp::initActions()
     // File actions
     //
     KStdAction::openNew( this, SLOT( slotFileNew()  ), actionCollection());
-    KStdAction::open   ( this, SLOT( slotFileOpen() ), actionCollection(), "qfile_open");
+    KStdAction::open   ( this, SLOT( slotFileOpen() ), actionCollection(), "file_open");
     KStdAction::close  ( this, SLOT( slotFileClose()), actionCollection());
 
     fileRecent =  KStdAction::openRecent(this, SLOT(slotFileOpenRecent(const KURL&)),
-                                         actionCollection(), "qfile_open_recent");
+                                         actionCollection(), "file_open_recent");
+    fileRecent->setMaxItems(32);
 
     (void) new KAction( i18n( "Close All" ), 0, this,
                         SLOT( slotFileCloseAll() ),
-                        actionCollection(), "close_all" );
+                        actionCollection(), "file_close_all" );
 
     saveAction = KStdAction::save(this, SLOT( slotFileSave() ),actionCollection());
 
@@ -1279,7 +1274,7 @@ void QuantaApp::initActions()
 
     saveAllAction = new KAction( i18n( "Save All..." ), UserIcon("save_all"), SHIFT+KStdAccel::key(KStdAccel::Save),
                         this, SLOT( slotFileSaveAll() ),
-                        actionCollection(), "save_all" );
+                        actionCollection(), "file_save_all" );
 
     saveAsLocalTemplateAction = new KAction( i18n( "Save As Local Template" ), 0,
                         this, SLOT( slotFileSaveAsLocalTemplate() ),
@@ -1418,6 +1413,7 @@ void QuantaApp::initActions()
       KStdAction::openRecent(project, SLOT(slotOpenProject(const KURL&)),
                              actionCollection(), "project_open_recent");
     project->projectRecent->setText(i18n("Open Recent Project..."));
+    project->projectRecent->setMaxItems(32);
 
     saveprjAction =  new KAction( i18n( "&Save Project" ), SmallIcon("save"), 0,
                          project, SLOT( slotSaveProject() ),
@@ -1583,13 +1579,10 @@ void QuantaApp::slotPluginsEdit()
   QuantaPluginEditor *editor = new QuantaPluginEditor(getView(), "plugin_editor");
   editor->setSearchPaths(m_pluginInterface->searchPaths());
   editor->setPlugins(m_pluginInterface->plugins());
-
-  if(editor->exec())
-  {
-    m_pluginInterface->setSearchPaths(editor->searchPathList());
-    m_pluginInterface->setPlugins(editor->plugins());
-    m_pluginInterface->writeConfig();
-  }
+  editor->exec();
+  m_pluginInterface->setSearchPaths(editor->searchPathList());
+  m_pluginInterface->setPlugins(editor->plugins());
+  m_pluginInterface->writeConfig();
 }
 
 void QuantaApp::slotPluginsValidate()
@@ -1611,5 +1604,3 @@ void QuantaApp::slotPluginsValidate()
   }
   statusBar()->message(i18n("All plugins validated successfully."));
 }
-
-
