@@ -31,17 +31,18 @@
 #include <qtextcodec.h>
 
 // include files for KDE
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <klocale.h>
 #include <kprocess.h>
-#include <kcolordlg.h>
+#include <kcolordialog.h>
 #include <kmessagebox.h>
 #include <kdeversion.h>
 
 #include <ktexteditor/configinterface.h>
 #include <ktexteditor/clipboardinterface.h>
 #include <ktexteditor/selectioninterface.h>
+#include <ktexteditor/markinterface.h>
 
 #if (KDE_VERSION > 308)
 #include <ktexteditor/dynwordwrapinterface.h>
@@ -145,7 +146,7 @@ void QuantaView::slotInsertCSS()
 
   delete dlg;*/
   QString code="";
-  
+
   uint line, col;
   w->viewCursorIf->cursorPositionReal(&line, &col);
 
@@ -199,13 +200,14 @@ void QuantaView::slotTagMail()
   	{
   		tag += QuantaCommon::attrCase(" href=\"")+"mailto:"+mailDlg->lineEmail->text();
   	  	if ( !QString(mailDlg->lineSubject->text()).isEmpty())
-	   		tag += "?subject="+mailDlg->lineSubject->text();
+	   		tag += "?subject="+KURL::encode_string(mailDlg->lineSubject->text());
   	   	tag += "\"";
   	}
 
   	if ( !QString(mailDlg->titleEdit->text()).isEmpty())
 	   		tag += QuantaCommon::attrCase(" title=\"")+mailDlg->titleEdit->text()+"\"";
     tag += QString(">");
+    tag.replace(QRegExp("\""), qConfig.attrValueQuotation);
     write()->insertTag(tag,QuantaCommon::tagCase("</a>"));
   }
   delete mailDlg;
@@ -248,11 +250,11 @@ void QuantaView::slotTagQuickStart(){
   if ( quickDlg->exec() )
    {
     const QString chset = QTextCodec::codecForLocale()->mimeName();
-    QString s = dtds->find(DEFAULT_DTD)->url;
-    if (!s.isEmpty()) s = "\n\t\t\"" + s + "\"";
-  	QString tag = QString("<!DOCTYPE HTML PUBLIC \""+DEFAULT_DTD+s+"\">\n")+QuantaCommon::tagCase("<html>\n")
-  	                  +space+QuantaCommon::tagCase("<head>\n")+space+QuantaCommon::tagCase("  <title>");
-  	if ( !QString(quickDlg->lineTitle->text()).isEmpty())
+
+    DTDStruct *dtd = write()->defaultDTD();
+    QString tag = QString("<!DOCTYPE" + dtd->doctypeStr +">\n")+QuantaCommon::tagCase("<html>\n")
+	                  + space + QuantaCommon::tagCase("<head>\n")+ space + QuantaCommon::tagCase("  <title>");
+    if ( !QString(quickDlg->lineTitle->text()).isEmpty())
 	   		tag += quickDlg->lineTitle->text();
     tag += QuantaCommon::tagCase("</title>\n")+space+
            "  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=" + chset + "\">\n"+
@@ -679,6 +681,9 @@ void QuantaView::slotCut ()
 void QuantaView::slotCopy ()
 {
   dynamic_cast<KTextEditor::ClipboardInterface*>(write()->view())->copy();
+  QClipboard *cb = QApplication::clipboard();
+  QString text = cb->text(QClipboard::Selection);
+  cb->setText(text, QClipboard::Clipboard);        
 }
 
 void QuantaView::slotPaste ()
@@ -701,6 +706,10 @@ void QuantaView::toggleVertical()
   dynamic_cast<KTextEditor::BlockSelectionInterface*>(write()->doc())->toggleBlockSelectionMode();
 }
 
+void QuantaView::toggleInsert()
+{
+  write()->kate_view->setOverwriteMode(!write()->kate_view->isOverwriteMode());
+}
 
 
 void QuantaView::slotFind ()
@@ -773,17 +782,31 @@ void QuantaView::slotSpellcheck ()
 
 void QuantaView::toggleBookmark ()
 {
-  write()->kate_view->toggleBookmark();
+  KTextEditor::MarkInterface *markIf = dynamic_cast<KTextEditor::MarkInterface*>(write()->doc());
+  uint line, col;
+  write()->viewCursorIf->cursorPositionReal(&line, &col);
+  int mark = markIf->mark(line);
+  if (mark == KTextEditor::MarkInterface::markType01)
+  {
+    markIf->removeMark(line, mark);
+  } else
+  {
+    markIf->addMark(line, KTextEditor::MarkInterface::markType01);
+  }
 }
 
 void QuantaView::clearBookmarks ()
 {
-  write()->kate_doc->clearMarks();
+  dynamic_cast<KTextEditor::MarkInterface*>(write()->doc())->clearMarks();
 }
 
 void QuantaView::gotoMark (KTextEditor::Mark *mark)
 {
-  write()->kate_view->gotoMark (mark);
+  if (mark->type == KTextEditor::MarkInterface::markType01)
+  {
+    Document *w = write();
+    w->viewCursorIf->setCursorPositionReal(mark->line, 0);
+  }
 }
 
 void QuantaView::toggleIconBorder ()
@@ -811,14 +834,16 @@ void QuantaView::slotEditorOptions()
   dynamic_cast<KTextEditor::ConfigInterface *>(write()->doc())->configDialog();
   write()->writeConfig(quantaApp->config);
   quantaApp->config->sync();
-  
+
   quantaApp->config->setGroup("Kate View");
   qConfig.lineNumbers = quantaApp->config->readBoolEntry("LineNumbers", false);
   qConfig.iconBar = quantaApp->config->readBoolEntry("Iconbar", false);
   qConfig.dynamicWordWrap = quantaApp->config->readBoolEntry("DynamicWordWrap",false);
   quantaApp->viewBorder->setChecked(qConfig.iconBar);
   quantaApp->viewLineNumbers->setChecked(qConfig.lineNumbers);
+#if (KDE_VERSION > 308)
   quantaApp->viewDynamicWordWrap->setChecked(qConfig.dynamicWordWrap);
+#endif
 }
 
 void QuantaView::setEol(int which)
@@ -849,7 +874,7 @@ void QuantaView::insertNewTag(QString tag, QString attr,bool insertInLine)
 
   delete dlg;
 }
-/** Returns the baseURL of the document. */    
+/** Returns the baseURL of the document. */
 KURL QuantaView::baseURL()
 {
   Document *w = write();
